@@ -1,7 +1,8 @@
 use std::collections::{BTreeMap, HashSet};
 use std::io::Write;
 use std::iter::once;
-use std::os::unix::prelude::ExitStatusExt;
+#[cfg(unix)]
+use std::os::unix::prelude::*;
 use std::path::{Path, PathBuf};
 use std::process::{exit, Stdio};
 use std::sync::atomic::{AtomicUsize, Ordering};
@@ -13,8 +14,8 @@ use console::Color;
 use demand::{DemandOption, Select};
 use duct::IntoExecutablePath;
 use either::Either;
-use eyre::Result;
-use globwalk::GlobWalkerBuilder;
+use eyre::{bail, ensure, eyre, Result};
+use glob::glob;
 use itertools::Itertools;
 use once_cell::sync::Lazy;
 
@@ -25,8 +26,7 @@ use crate::errors::Error::ScriptFailed;
 use crate::file::display_path;
 use crate::task::{Deps, GetMatchingExt, Task};
 use crate::toolset::{InstallOptions, ToolsetBuilder};
-use crate::ui::ctrlc;
-use crate::ui::style;
+use crate::ui::{ctrlc, style};
 use crate::{env, file, ui};
 
 use super::args::ToolArg;
@@ -47,7 +47,7 @@ use super::args::ToolArg;
 ///     outputs = ["dist/**/*.js"]
 ///
 /// Alternatively, tasks can be defined as standalone scripts.
-/// These must be located in the `.mise/tasks` directory.
+/// These must be located in the `.mise/tasks`, `mise/tasks` or `.config/mise/tasks` directory.
 /// The name of the script will be the name of the tasks.
 ///
 ///     $ cat .mise/tasks/build<<EOF
@@ -345,9 +345,12 @@ impl Run {
                 if let Some(code) = status.code() {
                     error!("{prefix} exited with code {code}");
                     exit(code);
-                } else if let Some(signal) = status.signal() {
-                    error!("{prefix} killed by signal {signal}");
-                    exit(1);
+                } else {
+                    #[cfg(unix)]
+                    if let Some(signal) = status.signal() {
+                        error!("{prefix} killed by signal {signal}");
+                        exit(1);
+                    }
                 }
             }
             error!("{err}");
@@ -476,7 +479,7 @@ impl Run {
 
 fn is_glob_pattern(path: &str) -> bool {
     // This is the character set used for glob
-    // detection by globwalk
+    // detection by glob
     let glob_chars = ['*', '{', '}'];
 
     path.chars().any(|c| glob_chars.contains(&c))
@@ -509,12 +512,24 @@ fn last_modified_glob_match(
     if patterns.is_empty() {
         return Ok(None);
     }
-    let files = GlobWalkerBuilder::from_patterns(root, patterns)
-        .follow_links(true)
-        .build()?
+    let files = patterns
+        .iter()
+        .flat_map(|pattern| {
+            glob(
+                root.as_ref()
+                    .join(pattern)
+                    .to_str()
+                    .expect("Conversion to string path failed"),
+            )
+            .unwrap()
+        })
         .filter_map(|e| e.ok())
-        .filter(|e| e.file_type().is_file())
-        .map(|e| e.path().to_owned());
+        .filter(|e| {
+            e.metadata()
+                .expect("Metadata call failed")
+                .file_type()
+                .is_file()
+        });
 
     last_modified_file(files)
 }
@@ -554,7 +569,7 @@ static AFTER_LONG_HELP: &str = color_print::cstr!(
 "#
 );
 
-#[derive(Debug, PartialEq, EnumString)]
+#[derive(Debug, PartialEq, strum::EnumString)]
 #[strum(serialize_all = "snake_case")]
 enum TaskOutput {
     Prefix,
@@ -586,10 +601,14 @@ fn format_duration(dur: std::time::Duration) -> String {
 
 #[cfg(test)]
 mod tests {
+    use insta::assert_snapshot;
+
     use crate::file;
+    use crate::test::reset;
 
     #[test]
     fn test_task_run() {
+        reset();
         file::remove_all("test-build-output.txt").unwrap();
         assert_cli_snapshot!(
             "r",
