@@ -11,6 +11,7 @@ use flate2::Compression;
 use itertools::Itertools;
 use serde_derive::{Deserialize, Serialize};
 
+use crate::env::PATH_KEY;
 use crate::{cmd, file};
 
 #[derive(Default, Serialize, Deserialize)]
@@ -161,7 +162,7 @@ fn valid_key(k: &str) -> bool {
     k.is_empty()
         || k == "_"
         || k == "SHLVL"
-        || k == "PATH"
+        || k == *PATH_KEY
         || k == "PWD"
         || k == "OLDPWD"
         || k == "HOME"
@@ -170,11 +171,7 @@ fn valid_key(k: &str) -> bool {
         || k == "SHELLOPTS"
         || k == "COMP_WORDBREAKS"
         || k == "PS1"
-        // TODO: consider removing this
-        // this is to make the ruby plugin compatible,
-        // it causes ruby to attempt to call asdf to reshim the binaries
-        // which we don't need or want to happen
-        || k == "RUBYLIB"
+        || k == "PROMPT_DIRTRIM"
         // following two ignores are for exported bash functions and exported bash
         // functions which are multiline, they appear in the environment as e.g.:
         // BASH_FUNC_exported-bash-function%%=() { echo "this is an"
